@@ -1,6 +1,6 @@
 package Elastic::Model::UID;
 {
-  $Elastic::Model::UID::VERSION = '0.12';
+  $Elastic::Model::UID::VERSION = '0.13';
 }
 
 use Moose;
@@ -82,7 +82,7 @@ sub new_from_store {
     my %params = %{ shift() };
     $class->new(
         from_store => 1,
-        routing    => $params{fields}{routing},
+        routing    => $params{fields}{_routing},
         map { $_ => $params{"_$_"} } qw(index type id version)
     );
 }
@@ -95,7 +95,7 @@ sub new_partial {
     $class->new(
         from_store => 1,
         is_partial => 1,
-        routing    => $params{fields}{routing},
+        routing    => $params{fields}{_routing},
         map { $_ => $params{"_$_"} } qw(index type id version)
     );
 }
@@ -167,7 +167,7 @@ Elastic::Model::UID - The Unique ID of a document in an ElasticSearch cluster
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
